@@ -1,7 +1,7 @@
 import time
 
 
-session_start_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time() - 0.1))
+session_start_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time() - 0.5))
 
 
 class Column:
@@ -16,19 +16,20 @@ class Column:
 
 
 default_columns = [
-    Column("TimeStamp", "Time", width=150, visible=True),
+    Column("TimeStamp", "Time", width=130, visible=True),
+    Column("LogLevel", "'Level#'", width=40, visible=False),
+    Column("LogLevelName", "Level", width=60, visible=True),
     Column("Source", width=200, visible=True),
-    Column("LogLevel", "Level#", width=100, visible=False),
-    Column("LogLevelName", "Level", width=80, visible=True),
-    Column("Message", width=100, visible=True),
-    Column("Args", width=100, visible=False),
     Column("Module", width=100, visible=False),
-    Column("FuncName", "Func", width=100, visible=False),
-    Column("LineNo", "Line", width=100, visible=False),
+    Column("FuncName || ':' || LineNo", "'Func:Line'", width=120, visible=True),
+    Column("FuncName", "Func", width=120, visible=False),
+    Column("LineNo", "Line", width=40, visible=False),
+    Column("Args", width=100, visible=False),
     Column("Exception", width=100, visible=False),
     Column("Process", width=100, visible=False),
     Column("Thread", width=100, visible=False),
     Column("ThreadName", width=100, visible=False),
+    Column("Message", width=100, visible=True),
 ]
 
 
@@ -37,7 +38,7 @@ class LogProfile:
         self.columns = default_columns
 
         self.loggers = {
-            'global': ['DEBUG','INFO','WARNING','ERROR','CRITICAL'],
+            'global': ['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'],
         }
         self.visible_loggers = ['global']
         self.text_filter = ''
@@ -58,16 +59,16 @@ class LogProfile:
         self.current_session_only = filt['current_session_only']
         self.query_limit = filt['query_limit']
 
-    def build_query(self):
+    def build_query(self, row_count):
         query = "SELECT "
 
         columns = []
         for col in self.columns:
             if col.visible:
                 if col.name != col.title:
-                    columns.append(f'"{col.name}" AS "{col.title}"')
+                    columns.append(f'{col.name} AS {col.title}')
                 else:
-                    columns.append(f'"{col.name}"')
+                    columns.append(f'{col.name}')
 
         query += ', '.join(columns)
         query += " FROM 'log'"
@@ -76,6 +77,9 @@ class LogProfile:
         if self.current_session_only:
             where.append(f"TimeStamp > '{session_start_time}'")
 
+        if self.query_limit:
+            where.append(f"rowid > {row_count - self.query_limit}")
+
         if self.text_filter:
             where.append(f"Message LIKE '%{self.text_filter}%'")
         
@@ -89,9 +93,6 @@ class LogProfile:
             where.append(f"({' OR '.join(sources)})")
 
         if where:
-            query += f' WHERE ' + ' AND '.join(where)
-        
-        if self.query_limit:
-            query += f" LIMIT {self.query_limit}"
+            query += ' WHERE ' + ' AND '.join(where)
 
-        return query
\ No newline at end of file
+        return query
