@@ -58,10 +58,12 @@ class LogMonitorWidget(QWidget):
 
 
 class LogMonitorDockWidget(QDockWidget):
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, shortcut='Ctrl+L'):
         super().__init__('Log Monitor', parent=parent)
         self.setObjectName('LogMonitor')
 
+        self.shortcut = shortcut
+
         self.setWidget(LogMonitorWidget(self))
 
         if command_palette_available:
@@ -86,29 +88,42 @@ class LogMonitorDockWidget(QDockWidget):
             
     def toggleViewAction(self):
         action = super().toggleViewAction()
-        action.setShortcut('Ctrl+L')
+        action.setShortcut(self.shortcut)
         return action
 
 
 class LogMonitorDropdown(QDialog):
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, shortcut='`'):
         super().__init__(parent=parent)
-        self.setWindowFlags(Qt.Tool | Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
+        self.setWindowFlags(Qt.Tool | Qt.FramelessWindowHint)
         self.setFocusPolicy(Qt.StrongFocus)
 
+        self.shortcut = shortcut
+
+        parent.installEventFilter(self)
+
         CHBoxLayout(self).add(LogMonitorWidget(self))
         
         if command_palette_available:
             self.commands = [
-                Command("Log Monitor: Show log monitor", triggered=self.show, shortcut='Ctrl+L'),
+                Command("Log Monitor: Show log monitor", triggered=self.show, shortcut=self.shortcut),
                 Command("Log Monitor: Hide log monitor", triggered=self.hide),
             ]
         
         self.hide()
 
+    def eventFilter(self, source: QObject, event: QEvent) -> bool:
+        if self.isVisible():
+            if isinstance(event, QMoveEvent):
+                self.center_on_parent()
+            if isinstance(event, QResizeEvent):
+                self.center_on_parent()
+
+        return super().eventFilter(source, event)
+
     def toggleViewAction(self):
         action = QAction("Toggle Log Monitor", self)
-        action.setShortcut('`')
+        action.setShortcut(self.shortcut)
         action.triggered.connect(self.toggle_view)
         return action
 
