@@ -14,9 +14,9 @@ class PersistentCheckBox(QCheckBox):
     
     def restore_state(self):
         prev_state = QSettings().value(self.name, 0)
-        if prev_state == int(Qt.Checked):
+        if prev_state == Qt.Checked:
             self.setCheckState(Qt.Checked)
-        elif prev_state == int(Qt.PartiallyChecked):
+        elif prev_state == Qt.PartiallyChecked:
             self.setCheckState(Qt.PartiallyChecked)
 
     def __bool__(self):
@@ -161,4 +161,4 @@ class PersistentCheckableAction(QAction):
             self.setChecked(False)
             
     def __bool__(self):
-        return self.checkState() == Qt.Checked
\ No newline at end of file
+        return self.isChecked()
\ No newline at end of file
